Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type API ¶
type API struct {
Types []APIClass
Functions []APIFunction
ErrorTypes []APIClass
Features []APIFeature
}
An API represents the API as advertised by Neovim
type APIFeature ¶
type APIFunction ¶
type APIFunction struct {
Name string
ReturnType string
ID uint32
CanFail bool
Deferred bool
ReceivesChannelID bool
Parameters []APIFunctionParameter
}
An APIFunction represents a class as defined as part of the API
type APIFunctionParameter ¶
type APIFunctionParameter struct {
Type, Name string
}
An APIFunctionParameter represents a function parameters as defined by an APIFunction
Click to show internal directories.
Click to hide internal directories.